sequencetools.get_sequence_elements_frequency_distribution
==========================================================

.. autofunction:: abjad.tools.sequencetools.get_sequence_elements_frequency_distribution.get_sequence_elements_frequency_distribution
